@@ -17,9 +17,10 @@ class CardLayout(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Card layout")
 
     def get_short_description(self):
-        text = "({})".format(self.card_type)
+        text = f"({self.card_type})"
         return text
 
 
@@ -31,17 +32,18 @@ class Card(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Card")
 
     def get_short_description(self):
-        if self.card_context and self.card_outline:
-            text = ".border-{}".format(self.card_context)
-        elif self.card_context:
-            text = ".bg-{}".format(self.card_context)
+        if self.config.get("background_context", False):
+            text = [f".bg-{self.background_context}"]
         else:
-            text = ""
+            text = []
+        if self.config.get("card_outline", False):
+            text.append(f".border-{self.card_outline}")
         if self.card_alignment:
-            text += " .{}".format(self.card_alignment)
-        return text
+            text.append(f".{self.card_alignment}")
+        return " ".join(text)
 
 
 class CardInner(FrontendUIItem):
@@ -52,6 +54,7 @@ class CardInner(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Card inner")
 
     def get_short_description(self):
         return "({})".format(self.inner_type.split("-", 1)[-1])
