@@ -1,3 +1,5 @@
+from django.utils.translation import gettext_lazy as _
+
 from djangocms_frontend.models import FrontendUIItem
 
 # TODO leaving this comment for now
@@ -16,9 +18,10 @@ class Collapse(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Collapse")
 
     def get_short_description(self):
-        return "(collapse-{})".format(str(self.pk))
+        return f"(collapse-{str(self.pk)})"
 
 
 class CollapseTrigger(FrontendUIItem):
@@ -29,9 +32,10 @@ class CollapseTrigger(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Collapse trigger")
 
     def get_short_description(self):
-        return "({})".format(self.trigger_identifier)
+        return f"({self.trigger_identifier})"
 
 
 class CollapseContainer(FrontendUIItem):
@@ -42,6 +46,7 @@ class CollapseContainer(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Collapse container")
 
     def get_short_description(self):
-        return "({})".format(self.container_identifier)
+        return f"({self.container_identifier})"
