@@ -7,7 +7,11 @@ from djangocms_frontend.common.background import BackgroundFormMixin
 from djangocms_frontend.common.responsive import ResponsiveFormMixin
 from djangocms_frontend.common.spacing import SpacingFormMixin
 from djangocms_frontend.contrib import jumbotron
-from djangocms_frontend.fields import AttributesFormField, TagTypeFormField
+from djangocms_frontend.fields import (
+    AttributesFormField,
+    TagTypeFormField,
+    TemplateChoiceMixin,
+)
 from djangocms_frontend.helpers import first_choice
 
 mixin_factory = settings.get_forms(jumbotron)
@@ -18,6 +22,7 @@ class JumbotronForm(
     ResponsiveFormMixin,
     SpacingFormMixin,
     BackgroundFormMixin,
+    TemplateChoiceMixin,
     EntangledModelForm,
 ):
     """
@@ -39,9 +44,6 @@ class JumbotronForm(
         label=_("Template"),
         choices=settings.JUMBOTRON_TEMPLATE_CHOICES,
         initial=first_choice(settings.JUMBOTRON_TEMPLATE_CHOICES),
-        widget=forms.HiddenInput
-        if len(settings.JUMBOTRON_TEMPLATE_CHOICES) < 2
-        else forms.Select,
     )
     jumbotron_fluid = forms.BooleanField(
         label=_("Fluid"),
