@@ -1,15 +1,18 @@
+from django.utils.translation import gettext as _
+
 from ...models import FrontendUIItem
 
 
 class Tab(FrontendUIItem):
     class Meta:
         proxy = True
+        verbose_name = _("Tab")
 
     def get_short_description(self):
-        text = "({})".format(self.tab_type)
+        text = f"({self.tab_type})"
 
         if self.tab_alignment:
-            text += " .{}".format(self.tab_alignment)
+            text += f" .{self.tab_alignment}"
         return text
 
 
@@ -21,6 +24,7 @@ class TabItem(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Tab item")
 
     def get_short_description(self):
         return self.tab_title
